@@ -15,7 +15,7 @@ class VaultHandler:
 
     def exec(self, profile, command, additional_args=""):
         try:
-            c = subprocess.Popen(
+            c = subprocess.Popen(  # pylint: disable=consider-using-with
                 f"aws-vault exec {profile} {additional_args} -- {command}",
                 stdout=subprocess.PIPE,
                 shell=True,
