@@ -1,4 +1,5 @@
 # -*- encoding: utf-8 -*-
+import logging
 import logzero
 from logzero import logger as _logger
 
@@ -6,6 +7,7 @@ DEFAULT_FORMAT = "%(color)s[%(levelname)1.4s]%(end_color)s %(message)s"
 # Set a custom formatter
 formatter = logzero.LogFormatter(fmt=DEFAULT_FORMAT)
 logzero.setup_default_logger(formatter=formatter)
+_logger.setLevel(logging.INFO)
 
 
 def setLevel(level):
